@@ -108,21 +108,31 @@ def load_checkpoint(checkpoint: str) -> ModelBase:
     Returns:
         - COMET Model
     """
+    if not os.path.exists(checkpoint):
+        raise Exception(f"{checkpoint} file not found!")
+    
     tags_csv_file = "/".join(checkpoint.split("/")[:-1] + ["meta_tags.csv"])
     hparam_yaml_file = "/".join(checkpoint.split("/")[:-1] + ["hparams.yaml"])
 
     if os.path.exists(tags_csv_file):
+        # Uggly convertion from older Lightning checkpoints 
         tags = pd.read_csv(
             tags_csv_file, header=None, index_col=0, squeeze=True
         ).to_dict()
+        hparams = {}
+        for k, v in tags.items():
+            if isinstance(v, str) and v.replace('.', '', 1).isdigit():
+                hparams[k] = float(v) if '.' in v else int(v)
+            else:
+                hparams[k] = v
         model = str2model[tags["model"]].load_from_checkpoint(
-            checkpoint, tags_csv=tags_csv_file
+            checkpoint, hparams=hparams
         )
     elif os.path.exists(hparam_yaml_file):
         with open(hparam_yaml_file) as yaml_file:
             hparams = yaml.load(yaml_file.read(), Loader=yaml.FullLoader)
         model = str2model[hparams["model"]].load_from_checkpoint(
-            checkpoint, hparams_file=hparam_yaml_file
+            checkpoint, hparams=hparams
         )
     else:
         raise Exception(
