@@ -55,7 +55,7 @@ class CometRanker(RankingBase):
             distance_neg.append(harmonic_distance_neg)
 
         return {
-            "kendall": self.metrics(torch.cat(distance_pos), torch.cat(distance_neg))
+            "kendall": self.metrics.compute(torch.cat(distance_pos), torch.cat(distance_neg))
         }
 
     def compute_loss(self, model_out: Dict[str, torch.Tensor], *args) -> torch.Tensor:
