@@ -5,10 +5,10 @@ import shutil
 import unittest
 import unittest.mock
 
+from comet.models import (CometEstimator, download_model, load_checkpoint,
+                          model2download)
 from tests.data import DATA_PATH
 
-from comet.models import CometEstimator, download_model, model2download
-
 
 class TestDownload(unittest.TestCase):
     @classmethod
@@ -16,6 +16,13 @@ class TestDownload(unittest.TestCase):
         shutil.rmtree(DATA_PATH + "wmt-base-da-estimator-1719")
         # os.remove(DATA_PATH + "public-models.yaml")
 
+    def test_load_unvalid_checkpoint(self):
+        with self.assertRaises(Exception) as context:
+            load_checkpoint("folder/that/does/not/exist/")
+        self.assertEqual(
+            str(context.exception), "folder/that/does/not/exist/ file not found!"
+        )
+        
     def test_model2download(self):
         model2link = model2download(DATA_PATH)
         self.assertTrue(os.path.exists(DATA_PATH + "public-models.yaml"))
